# Flow Monitor

A real-time flow data monitoring tool with a GUI.

## Features

- Real-time data visualization.
- Serial data parsing.
- Interactive graphs and data tables.

## Installation

```bash
pip install flow_monitor